OC.L10N.register(
    "files",
    {
    "File could not be found" : "Dosya bulunamadı",
    "Move or copy" : "Taşı ya da kopyala",
    "Download" : "İndir",
    "Delete" : "Sil",
    "Tags" : "Etiketler",
    "Show list view" : "Liste görünümüne geç",
    "Show grid view" : "Tablo görünümüne geç",
    "Home" : "Giriş",
    "Close" : "Kapat",
    "Could not create folder \"{dir}\"" : "\"{dir}\" klasörü oluşturulamadı",
    "This will stop your current uploads." : "Bu işlem geçerli yüklemeleri durduracak.",
    "Upload cancelled." : "Yükleme iptal edildi.",
    "Processing files …" : "Dosyalar işleniyor …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir klasör ya da 0 bayt boyutunda olduğundan yüklenemedi",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterli boş alan yok. Yüklemek istediğiniz boyut {size1} ancak yalnızca {size2} boş alan var",
    "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" hedef klasörü artık yok",
    "Not enough free space" : "Yeterli boş alan yok",
    "An unknown error has occurred" : "Bilinmeyen bir sorun çıktı",
    "File could not be uploaded" : "Dosya yüklenemedi",
    "Uploading …" : "Yükleniyor …",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Yükleniyor… ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Bu ögenin yüklenmesi desteklenmiyor",
    "Target folder does not exist any more" : "Hedef klasör artık yok",
    "Operation is blocked by access control" : "İşlem erişim denetimi tarafından engellendi",
    "Error when assembling chunks, status code {status}" : "Kümeler oluşturulurken sorun çıktı, durum kodu {status}",
    "Actions" : "İşlemler",
    "Rename" : "Yeniden adlandır",
    "Move" : "Taşı",
    "Copy" : "Kopyala",
    "Choose target folder" : "Hedef klasörü seçin",
    "Set reminder" : "Anımsatıcı ayarla",
    "Edit locally" : "Yerel olarak düzenle",
    "Open" : "Aç",
    "Delete file" : "Dosyayı sil",
    "Delete folder" : "Klasörü sil",
    "Disconnect storage" : "Depolama bağlantısını kes",
    "Leave this share" : "Bu paylaşımdan ayrıl",
    "Could not load info for file \"{file}\"" : "\"{file}\" dosyasının bilgileri alınamadı",
    "Files" : "Dosyalar",
    "Details" : "Ayrıntılar",
    "Please select tag(s) to add to the selection" : "Seçime eklemek için etiketleri seçin",
    "Apply tag(s) to selection" : "Etiketleri seçime uygula",
    "Select directory \"{dirName}\"" : "\"{dirName}\" klasörünü seçin",
    "Select file \"{fileName}\"" : "\"{fileName}\" dosyasını seçin",
    "Pending" : "Bekliyor",
    "Unable to determine date" : "Tarih belirlenemedi",
    "This operation is forbidden" : "Bu işleme izin verilmiyor",
    "This directory is unavailable, please check the logs or contact the administrator" : "Bu klasör yazılabilir değil. Lütfen günlük kayıtlarına bakın ya da BT yöneticiniz ile görüşün",
    "Storage is temporarily not available" : "Depolama geçici olarak kullanılamıyor",
    "Could not move \"{file}\", target exists" : "\"{file}\" taşınamadı, hedef zaten var",
    "Could not move \"{file}\"" : "\"{file}\" taşınamadı",
    "copy" : "kopya",
    "Could not copy \"{file}\", target exists" : "\"{file}\" dosyası kopyalanamadı, hedef zaten var",
    "Could not copy \"{file}\"" : "\"{file}\" kopyalanamadı",
    "Copied {origin} inside {destination}" : "{origin} dosyası, {destination} içine kopyalandı",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} ve diğer {nbfiles} dosya, {destination} içine kopyalandı",
    "Failed to redirect to client" : "İstemciye yönlendirilemedi",
    "{newName} already exists" : "{newName} zaten var",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" yeniden adlandırılamadı, artık yok",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" adı \"{dir}\" klasöründe zaten var. Lütfen farklı bir ad seçin.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" yeniden adlandırılamadı",
    "Could not create file \"{file}\"" : "\"{file}\" dosyası oluşturulamadı",
    "Could not create file \"{file}\" because it already exists" : "\"{file}\" dosyası zaten var olduğundan oluşturulamadı",
    "Could not create folder \"{dir}\" because it already exists" : "\"{dir}\" klasörü zaten var olduğundan oluşturulamadı",
    "Could not fetch file details \"{file}\"" : "\"{file}\" dosyasının ayrıntıları alınamadı",
    "Error deleting file \"{fileName}\"." : "\"{fileName}\" dosyası silinirken sorun çıktı.",
    "No search results in other folders for {tag}{filter}{endtag}" : "{tag}{filter}{endtag} için diğer klasörlerde herhangi bir arama sonucu yok",
    "Enter more than two characters to search in other folders" : "Diğer klasörlerde aramak için iki karakterden fazla yazın",
    "Name" : "Ad",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme",
    "_%n folder_::_%n folders_" : ["%n klasör","%n klasör"],
    "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
    "{dirs} and {files}" : "{dirs} ve {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n gizli ile birlikte","%n gizli ile birlikte"],
    "You do not have permission to upload or create files here" : "Buraya dosya yükleme ya da ekleme izniniz yok",
    "_Uploading %n file_::_Uploading %n files_" : ["%n dosya yükleniyor","%n dosya yükleniyor"],
    "New" : "Yeni",
    "New file/folder menu" : "Yeni dosya/klasör menüsü",
    "Select file range" : "Dosya aralığını seçin",
    "{used}%" : "%{used}",
    "{used} of {quota} used" : "{used} / {quota} kullanılmış",
    "{used} used" : "{used} kullanılmış",
    "\"{name}\" is an invalid file name." : "\"{name}\" geçersiz bir dosya adı.",
    "File name cannot be empty." : "Dosya adı boş olamaz.",
    "\"/\" is not allowed inside a file name." : "Dosya adında \"/\" kullanılamaz.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" dosya türüne izin verilmiyor",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} için boş depolama alanı kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{mountPoint}\" grup klasöründe boş alan kalmadı. Artık güncellenemeyecek ya da eşitlenemeyecek!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "\"{mountPoint}\" dış depolamasında boş alan kalmadı. Artık güncellenemeyecek ya da eşitlenemeyecek!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Boş depolama alanınız kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} boş depolama alanı bitmek üzere ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" grup klasöründeki boş alan bitmek üzere ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" dış depolamasındaki boş alan bitmek üzere ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Boş depolama alanınız bitmek üzere ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["\"{filter}\" ile eşleşiyor","\"{filter}\" ile eşleşiyor"],
    "View in folder" : "Klasörde görüntüle",
    "Direct link was copied (only works for people who have access to this file/folder)" : "Doğrudan bağlantı kopyalandı (yalnızca bu dosya ya da klasöre erişim izni olan kişiler kullanabilir)",
    "Path" : "Yol",
    "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
    "Favorited" : "Sık kullanılanlara eklendi",
    "Favorite" : "Sık kullanılanlara ekle",
    "Copy direct link (only works for people who have access to this file/folder)" : "Doğrudan bağlantıyı kopyala (yalnızca bu dosya ya da klasöre erişim izni olan kişiler için)",
    "New folder" : "Yeni klasör",
    "Create new folder" : "Klasör ekle",
    "Upload file" : "Dosya yükle",
    "Recent" : "Son",
    "Not favorited" : "Sık kullanılanlarda değil",
    "Remove from favorites" : "Sık kullanılanlardan kaldır",
    "Add to favorites" : "Sık kullanılanlara ekle",
    "An error occurred while trying to update the tags" : "Etiketler güncellenirken bir sorun çıktı",
    "Added to favorites" : "Sık kullanılanlara eklendi",
    "Removed from favorites" : "Sık kullanılanlardan çıkarıldı",
    "You added {file} to your favorites" : "{file} dosyasını sık kullandıklarınıza eklediniz",
    "You removed {file} from your favorites" : "{file} dosyasını sık kullandıklarınızdan çıkardınız",
    "Favorites" : "Sık kullanılanlar",
    "File changes" : "Dosya değişikleri",
    "Created by {user}" : "{user} tarafından eklendi",
    "Changed by {user}" : "{user} tarafından değiştirildi",
    "Deleted by {user}" : "{user} tarafından silindi",
    "Restored by {user}" : "{user} tarafından geri yüklendi",
    "Renamed by {user}" : "{user} tarafından adı değiştirildi",
    "Moved by {user}" : "{user} tarafından taşındı",
    "\"remote account\"" : "\"uzak hesap\"",
    "You created {file}" : "{file} dosyasını eklediniz",
    "You created an encrypted file in {file}" : "{file} içinde şifrelenmiş bir dosya oluşturdunuz",
    "{user} created {file}" : "{user}, {file} dosyasını ekledi",
    "{user} created an encrypted file in {file}" : "{user} kullanıcısı {file} içinde şifrelenmiş bir dosya oluşturdu",
    "{file} was created in a public folder" : "{file} dosyası herkese açık klasör içine eklendi",
    "You changed {file}" : "{file} dosyasını değiştirdiniz",
    "You changed an encrypted file in {file}" : "{file} içindeki şifrelenmiş bir dosyayı değiştirdiniz",
    "{user} changed {file}" : "{user}, {file} dosyasını değiştirdi",
    "{user} changed an encrypted file in {file}" : "{user} kullanıcısı {file} içindeki şifrelenmiş bir dosyayı değiştirdi",
    "You deleted {file}" : "{file} dosyasını sildiniz",
    "You deleted an encrypted file in {file}" : "{file} içindeki şifrelenmiş bir dosyayı sildiniz",
    "{user} deleted {file}" : "{user}, {file} dosyasını sildi",
    "{user} deleted an encrypted file in {file}" : "{user} kullanıcısı {file} içindeki şifrelenmiş bir dosyayı sildi",
    "You restored {file}" : "{file} dosyasını geri yüklediniz",
    "{user} restored {file}" : "{user}, {file} dosyasını geri yükledi",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "{oldfile} (gizli) dosyasını {newfile} (gizli) olarak yeniden adlandırdınız",
    "You renamed {oldfile} (hidden) to {newfile}" : "{oldfile} (gizli) dosyasını {newfile} olarak yeniden adlandırdınız",
    "You renamed {oldfile} to {newfile} (hidden)" : "{oldfile} dosyasını {newfile} (gizli) olarak yeniden adlandırdınız",
    "You renamed {oldfile} to {newfile}" : "{oldfile} dosyasının adını {newfile} olarak değiştirdiniz",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "[user], {oldfile} (gizli) dosyasını {newfile} (gizli) olarak yeniden adlandırdı",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "[user], {oldfile} (gizli) dosyasını {newfile} olarak yeniden adlandırdı",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "[user], {oldfile} dosyasını {newfile} (gizli) olarak yeniden adlandırdı",
    "{user} renamed {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının adını {newfile} olarak değiştirdi",
    "You moved {oldfile} to {newfile}" : "{oldfile} dosyasını {newfile} klasörüne taşıdınız",
    "{user} moved {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının {newfile} dosyasına taşıdı",
    "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>Sık kullandıklarınıza</strong> bir dosya eklendi ya da silindi",
    "A file or folder has been <strong>changed</strong>" : "Bir dosya ya da klasör <strong>değiştirildiğinde</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Sık kullanılan bir dosya ya da klasör <strong>değiştirildiğinde</strong>",
    "Upload (max. %s)" : "Yükle (en büyük: %s)",
    "Accept" : "Kabul et",
    "Reject" : "Reddet",
    "Incoming ownership transfer from {user}" : "{user} kullanıcısından gelen sahiplik aktarımı ",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path} yolunu onaylamak istiyor musunuz?\n\nNot: Onay verdikten sonra aktarım işleminin tamamlanması 1 saat kadar sürebilir.",
    "Ownership transfer failed" : "Sahiplik aktarılamadı",
    "Your ownership transfer of {path} to {user} failed." : "{path} yolundaki sahipliğiniz {user} kullanıcısına aktarılamadı.",
    "The ownership transfer of {path} from {user} failed." : "{path} yolundaki {user} kullanıcısının sahipliği size aktarılamadı.",
    "Ownership transfer done" : "Sahiplik aktarıldı",
    "Your ownership transfer of {path} to {user} has completed." : "{path} yolundaki sahipliğiniz {user} kullanıcısına aktarıldı.",
    "The ownership transfer of {path} from {user} has completed." : "{path} yolundaki {user} kullanıcısının sahipliği size aktarıldı.",
    "in %s" : "%s içinde",
    "File Management" : "Dosya yönetimi",
    "Current directory path" : "Geçerli klasör yolu",
    "Reload current directory" : "Geçerli klasörü yeniden yükle",
    "Go to the \"{dir}\" directory" : "\"{dir}\" klasörüne git",
    "Drag and drop files here to upload" : "Yüklemek istediğiniz dosyaları sürükleyip buraya bırakın",
    "Your have used your space quota and cannot upload files anymore" : "Depolama alanınızın tümünü kullandığınız için başka dosya yüklemezsiniz",
    "You don’t have permission to upload or create files here" : "Buraya dosya yükleme ya da ekleme izniniz yok",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" işlemi tamamlandı",
    "\"{displayName}\" action failed" : "\"{displayName}\" işlemi tamamlanamadı",
    "Toggle selection for file \"{displayName}\"" : "\"{displayName}\" dosyasını seç/bırak",
    "Toggle selection for folder \"{displayName}\"" : "\"{displayName}\" klasörünü seç/bırak",
    "Rename file" : "Dosyayı yeniden adlandır",
    "File name" : "Dosya adı",
    "Folder name" : "Klasör adı",
    "This node is unavailable" : "Bu düğüm kullanılamıyor",
    "Download file {name}" : "{name} dosyasını indir",
    "Invalid file name" : "Dosya adı geçersiz",
    "\"{name}\" is not an allowed filetype." : "\"{name}\" dosya türüne izin verilmiyor.",
    "{newName} already exists." : "{newName} zaten var.",
    "\"{char}\" is not allowed inside a file name." : "Dosya adlarında \"{char}\" karakteri kullanılamaz.",
    "Name cannot be empty" : "Ad boş olamaz",
    "Another entry with the same name already exists" : "Aynı adlı bir kayıt zaten var",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" adı \"{newName}\" olarak değiştirildi",
    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" adı artık olmadığından değiştirilemedi. ",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" adı \"{dir}\" klasöründe zaten kullanılmış. Lütfen başka bir ad seçin.",
    "Could not rename \"{oldName}\"" : "\"{oldName}\" adı değiştirilemedi",
    "Total rows summary" : "Toplam satır özeti",
    "Toggle selection for all files and folders" : "Tüm dosyaları ve klasörleri seç/bırak",
    "\"{displayName}\" failed on some elements " : "\"{displayName}\" toplu işlemi bazı bileşenlerde tamamlanamadı",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" toplu işlemi tamamlandı",
    "{count} selected" : "{count} seçilmiş",
    "List of files and folders." : "Dosya ve klasörlerin listesi.",
    "Column headers with buttons are sortable." : "Düğmeler olan sütunlar sıralanabilir.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Başarımı olumsuz etkilememek için listenin tümü görüntülenmiyor. Listede ilerledikçe dosyalar görüntülenecek.",
    "File not found" : "Dosya bulunamadı",
    "Storage informations" : "Depolama bilgileri",
    "{usedQuotaByte} used" : "{usedQuotaByte} kullanılmış",
    "{relative}% used" : "%{relative} kullanılmış",
    "Could not refresh storage stats" : "Depolama istatistikleri yenilenemedi",
    "Your storage is full, files can not be updated or synced anymore!" : "Boş depolama alanınız kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
    "Create" : "Ekle",
    "A file or folder with that name already exists." : "Aynı adlı bir dosya ya da klasör zaten var.",
    "Transfer ownership of a file or folder" : "Bir dosya ya da klasörün sahipliğini aktarabilirsiniz",
    "Choose file or folder to transfer" : "Sahipliği aktarılacak dosya ya da klasörü seçin",
    "Change" : "Değiştir",
    "New owner" : "Yeni sahip",
    "Choose a file or folder to transfer" : "Sahipliği aktarılacak bir dosya ya da klasör seçin",
    "Transfer" : "Sahipliği aktar",
    "Transfer {path} to {userid}" : "{path} yolunun sahipliğini {userid} kullanıcısına aktar",
    "Invalid path selected" : "Seçilen yol geçersiz",
    "Unknown error" : "Bilinmeyen sorun",
    "Ownership transfer request sent" : "Sahiplik aktarımı isteği gönderildi",
    "Cannot transfer ownership of a file or folder you do not own" : "Sahibi olmadığınız bir dosya ya da klasörün sahipliğini aktaramazsınız",
    "Select file or folder to link to" : "Bağlantı verilecek dosya ya da klasörü seçin",
    "Choose file" : "Dosya seçin",
    "Choose {file}" : "{file} seçin",
    "Loading current folder" : "Geçerli klasör yükleniyor",
    "No files in here" : "Burada herhangi bir dosya yok",
    "Upload some content or sync with your devices!" : "Bir şeyler yükleyin ya da aygıtlarınızla eşitleyin!",
    "Go to the previous folder" : "Önceki klasöre git",
    "Go back" : "Geri dön",
    "Share" : "Paylaş",
    "Shared by link" : "Bağlantı ile paylaşılmış",
    "Shared" : "Paylaşılan",
    "Switch to list view" : "Liste görünümüne geç",
    "Switch to grid view" : "Tablo görünümüne geç",
    "Error during upload: {message}" : "Yükleme sırasında sorun çıktı: {message}",
    "Error during upload, status code {status}" : "Yüklenirken sorun çıktı, durum kodu {status}",
    "Unknown error during upload" : "Yükleme sırasında bilinmeyen bir sorun çıktı",
    "Open the files app settings" : "Dosyalar uygulaması ayarlarını aç",
    "Files settings" : "Dosyalar ayarları",
    "File cannot be accessed" : "Dosyaya erişilemedi",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Dosya bulunamadı ya da görüntüleme izniniz olmayabilir. Gönderenden paylaşmasını isteyin",
    "Your files" : "Dosyalarınız",
    "Open in files" : "Dosyalar uygulamasında aç",
    "Sort favorites first" : "Sık kullanılanlar üstte sıralansın",
    "Sort folders before files" : "Klasörler dosyaların üzerinde sıralansın",
    "Show hidden files" : "Gizli dosyaları görüntüle",
    "Crop image previews" : "Görsel ön izlemeleri kırpılsın",
    "Enable the grid view" : "Tablo görünümü kullanılsın",
    "Additional settings" : "Ek ayarlar",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV adresi",
    "Copy to clipboard" : "Panoya kopyala",
    "Use this address to access your Files via WebDAV" : "Dosyalarınıza WebDAV üzerinden erişmek için bu adresi kullanın",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "İki adımlı doğrulamayı etkinleştirdiyseniz buraya tıklayarak yeni bir uygulama parolası oluşturmalısınız.",
    "Clipboard is not available" : "Pano kullanılamıyor",
    "WebDAV URL copied to clipboard" : "WebDAV adresi panoya kopyalandı",
    "Unable to change the favourite state of the file" : "Dosyanın sık kullanılan durumu değiştirilemedi",
    "Error while loading the file data" : "Dosya verileri yüklenirken sorun çıktı",
    "Pick a template for {name}" : "{name} için bir kalıp seçin",
    "Create a new file with the selected template" : "Seçilmiş kalıp ile yeni bir dosya ekle",
    "Creating file" : "Dosya ekleniyor",
    "Blank" : "Boş",
    "Unable to create new file from template" : "Kalıptan yeni dosya eklenemedi",
    "Delete permanently" : "Kalıcı olarak sil",
    "Delete and unshare" : "Sil ve paylaşımdan kaldır",
    "Leave these shares" : "Bu paylaşımlardan ayrıl",
    "Disconnect storages" : "Depolama alanlarının bağlantısını kes",
    "Delete files" : "Dosyaları sil",
    "Delete folders" : "Klasörleri sil",
    "You are about to delete {count} items." : "{count} ögeyi silmek üzeresiniz.",
    "Confirm deletion" : "Silmeyi onaylayın",
    "Cancel" : "İptal",
    "Deletion cancelled" : "Silme iptal edildi",
    "Destination is not a folder" : "Hedef bir klasör değil",
    "This file/folder is already in that directory" : "Dosya ya da klasör bu klasörde zaten var",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Bir dosyayı ya da klasörü kendi üzerine veya kendisinin alt klasörüne taşıyamazsınız",
    "(copy)" : "(kopya)",
    "(copy %n)" : "(%n kopyası)",
    "Move cancelled" : "Taşıma iptal edildi",
    "A file or folder with that name already exists in this folder" : "Bu klasörde aynı adlı bir dosya ya da klasör zaten var",
    "The files are locked" : "Dosyalar kilitli",
    "The file does not exist anymore" : "Dosya artık yok",
    "Choose destination" : "Hedefi seçin",
    "Copy to {target}" : "{target} içine kopyala",
    "Move to {target}" : "{target} içine taşı",
    "Cancelled move or copy operation" : "Taşıma ya da kopyalama işlemi iptal edildi",
    "Move or copy operation failed" : "Taşıma ya da kopyalama yapılamadı",
    "Open folder {displayName}" : "{displayName} klasörünü aç",
    "Open in Files" : "Dosyalar uygulamasında aç",
    "Open details" : "Ayrıntıları aç",
    "Created new folder \"{name}\"" : "\"{name}\" yeni klasörü oluşturuldu",
    "Filename" : "Dosya adı",
    "Unable to initialize the templates directory" : "Kalıp klasörü hazırlanamadı",
    "Create new templates folder" : "Yeni kalıp klasörü oluştur",
    "Templates" : "Kalıplar",
    "New template folder" : "Yeni kalıp klasörü",
    "In folder" : "Klasörde",
    "Search in folder: {folder}" : "Şu klasörde ara: {folder}",
    "One of the dropped files could not be processed" : "Bırakılan dosyalardan biri işlenemedi",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Tarayıcınız dosya sistemi API uygulamasını desteklemiyor. Klasörler yüklenemeyecek",
    "No files to upload" : "Yüklenecek bir dosya yok",
    "Unable to create the directory {directory}" : "{directory} klasörü oluşturulamadı",
    "Some files could not be uploaded" : "Bazı dosyalar yüklenemedi",
    "Files uploaded successfully" : "Dosyalar yüklendi",
    "No files to process" : "İşlenecek bir dosya yok",
    "Some files could not be copied" : "Bazı dosyalar kopyalanamadı",
    "Some files could not be moved" : "Bazı dosyalar taşınamadı",
    "Files copied successfully" : "Dosyalar kopyalandı",
    "Files moved successfully" : "Dosyalar taşındı",
    "Conflicts resolution skipped" : "Çakışma çözümleme atlandı",
    "Upload cancelled" : "Yükleme iptal edildi",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} klasör","{folderCount} klasör"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} dosya","{fileCount} dosya"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 dosya ve {folderCount} klasör","1 dosya ve {folderCount} klasör"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} dosya ve 1 klasör","{fileCount} dosya ve 1 klasör"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} dosya ve {folderCount} klasör",
    "List of favorites files and folders." : "Sık kullanılan dosya ve klasör listesi.",
    "No favorites yet" : "Henüz sık kullanılan bir öge yok",
    "Files and folders you mark as favorite will show up here" : "Sık kullanılanlara eklediğiniz dosya ve klasörler burada görüntülenir",
    "All files" : "Tüm dosyalar",
    "List of your files and folders." : "Dosya ve klasörlerinizin listesi",
    "Personal Files" : "Kişisel dosyalar",
    "List of your files and folders that are not shared." : "Paylaşılmayan dosya ve klasörlerinizin listesi.",
    "No personal files found" : "Herhangi bir kişisel dosya bulunamadı",
    "Files that are not shared will show up here." : "Paylaşımayan dosyalar burada görüntülenir.",
    "List of recently modified files and folders." : "Son değiştirilen dosya ve klasörlerin listesi.",
    "No recently modified files" : "Yakınlarda değiştirilmiş bir dosya yok",
    "Files and folders you recently modified will show up here." : "Son zamanlarda değiştirdiğiniz dosya ve klasörler burada görüntülenir.",
    "No entries found in this folder" : "Bu klasörde herhangi bir kayıt bulunamadı",
    "Select all" : "Tümünü seç",
    "Upload too large" : "Yükleme boyutu çok büyük",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yüklemeye çalıştığınız dosyalar bu sunucuya yüklenmesine izin verilen en büyük dosya boyutunu aşıyor.",
    "Text file" : "Metin dosyası",
    "New text file.txt" : "Yeni metin dosyası.txt",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Doğrudan bağlantı kopyalandı (yalnızca bu dosya ya da klasöre erişim izni olan kullanıcılar kullanabilir)",
    "Copy direct link (only works for users who have access to this file/folder)" : "Doğrudan bağlantıyı kopyala (yalnızca bu dosya ya da klasöre erişim izni olan kullanıcılar için)",
    "You can only favorite a single file or folder at a time" : "Aynı anda yalnızca bir dosya ya da bir klasör sık kullanılanlara eklenebilir",
    "This file has the tag {tag}" : "Dosya {tag} olarak etiketlenmiş",
    "This file has the tags {firstTags} and {lastTag}" : "Dosya {firstTags} ve {lastTag} olarak etiketlenmiş",
    "\"remote user\"" : "\"uzak kullanıcı\"",
    "Select the row for {displayName}" : "{displayName} satırını seç",
    "Open folder {name}" : "{name} klasörünü aç",
    "Unselect all" : "Tümünü bırak",
    "ascending" : "Artan",
    "descending" : "Azalan",
    "Sort list by {column} ({direction})" : "Listeyi {column} sütununa göre sırala ({direction})",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Başarımı olumsuz etkilememek için listenin tümü görüntülenmiyor. Listede ilerledikçe dosyalar görüntülenecek.",
    "Search for an account" : "Hesap ara",
    "Choose" : "Seçin",
    "No files or folders have been deleted yet" : "Henüz silinmiş bir dosya ya da klasör yok",
    "You might not have have permissions to view it, ask the sender to share it" : "Dosyayı görüntüleme izniniz olmayabilir. Gönderenden paylaşmasını isteyin",
    "Set up templates folder" : "Kalıp klasörünü ayarlayın",
    "Toggle %1$s sublist" : "%1$s alt listesini aç/kapat",
    "Toggle grid view" : "Tablo görünümünü aç/kapat",
    "Shares" : "Paylaşımlar",
    "Shared with others" : "Başkalarıyla paylaşılan",
    "Shared with you" : "Sizinle paylaşılan",
    "Deleted shares" : "Silinmiş paylaşımlar",
    "Pending shares" : "Bekleyen paylaşımlar",
    "The files is locked" : "Dosyalar kilitli"
},
"nplurals=2; plural=(n > 1);");
